# Test Informal

[Gimpformats Index](../README.md#gimpformats-index) / Test Informal

> Auto-generated documentation for [test_informal](../../../test_informal/__init__.py) module.

- [Test Informal](#test-informal)
  - [Modules](#modules)

## Modules

- [Test Gimp Document](./test_gimp_document.md)
- [Test Native Convert](./test_native_convert.md)